@@ -1030,10 +1030,10 @@ GVApi::lookForLoginErrorMessage(const QString &resp, AsyncTaskToken *task)
     } while (0);
 
     if (task->errorString.isEmpty()) {
+        Q_WARN("Couldn't figure out why Google denied login :(");
+
         task->errorString = tr("The username or password you entered "
                                "is incorrect.");
-    } else {
-        Q_WARN("Couldn't figure out why Google denied login :(");
     }
 }//GVApi::lookForLoginErrorMessage
 
@@ -2259,6 +2259,15 @@ GVApi::onCallback(bool success, const QByteArray &response, QNetworkReply *,
                 break;
             }
 
+            QString errMsg = scriptEngine.evaluate ("obj.error").toString ();
+            if (scriptEngine.hasUncaughtException ()) {
+                Q_WARN("Failed to parse error: ") << strReply;
+            }
+
+            if (!errMsg.isEmpty ()) {
+                token->errorString = errMsg;
+            }
+
             if (1 == code) {
                 Q_WARN("Cannot start a new dial back call while there is one "
                        "in progress.");
