@@ -39,6 +39,10 @@ Contact: yuvraaj@gmail.com
 #include "GVNumModel.h"
 #include "ContactNumbersModel.h"
 
+#ifdef MAIN_QML_PATH
+#error Undefine this shit
+#endif
+
 #ifndef QGV_NO_DEFAULT_APP_OBJECTS
 QApplication *
 createSingleAppObject(int &argc, char **argv)
@@ -143,7 +147,7 @@ QmlMainWindow::init()
         return;
     }
 
-    m_view->setMainQmlFile(QLatin1String(MAIN_QML_PATH));
+    m_view->setMainQmlFile(getMainQmlPath());
     m_view->setOrientation(QmlApplicationViewer::ScreenOrientationAuto);
     m_view->showExpanded();
 
@@ -200,6 +204,19 @@ QmlMainWindow::onViewerStatusChanged(bool /*ready*/)
     }
 }//QmlMainWindow::onViewerStatusChanged
 
+void
+QmlMainWindow::dumpMetaMethods(QObject *obj)
+{
+    const QMetaObject* metaObject = obj->metaObject();
+    for(int i = metaObject->methodOffset(); i < metaObject->methodCount(); ++i) {
+#if QT_VERSION >= QT_VERSION_CHECK(5,0,0)
+        Q_DEBUG(QString::fromLatin1(metaObject->method(i).methodSignature()));
+#else
+        Q_DEBUG(QString::fromLatin1(metaObject->method(i).signature()));
+#endif
+    }
+}//QmlMainWindow::dumpMetaMethods
+
 bool
 QmlMainWindow::initQmlObjects()
 {
@@ -394,6 +411,8 @@ QmlMainWindow::initQmlObjects()
                                       this,
                                       SLOT(onEdInboxUpdateTextChanged()));
 
+        initDerivedQmlObjects();
+
         onInitDone();
         rv = true;
     } while(0);
