@@ -73,8 +73,12 @@ protected slots:
 
 protected:
     QObject *getQMLObject(const char *pageName);
+    void dumpMetaMethods(QObject *obj);
 
     bool initQmlObjects();
+    virtual void initDerivedQmlObjects() {}
+
+    virtual QString getMainQmlPath() = 0;
 
     void uiUpdateProxySettings(const ProxyInfo &info);
     void uiRequestLoginDetails();
