@@ -59,7 +59,7 @@ CacheDatabase::init ()
 {
     OsDependent &osd = Singletons::getRef().getOSD ();
     QString strDbFile, strIniFile;
-    strDbFile = osd.getAppDirectory () + QDir::separator ();
+    strDbFile = osd.getDbDirectory () + QDir::separator ();
     strIniFile = strDbFile;
     strDbFile += QGVDIAL_DB_NAME;
     strIniFile += QGVDIAL_INI_NAME;
@@ -79,9 +79,6 @@ CacheDatabase::init ()
         return;
     }
 
-    QSqlQuery query(dbMain);
-    query.setForwardOnly (true);
-
     bool bBlowAway = true;
     QString strVer = settings->value(GV_S_VAR_DB_VER).toString();
     if (strVer == GV_S_VALUE_DB_VER) {
@@ -219,7 +216,7 @@ CacheDatabase::setQuickAndDirty (bool bBeDirty)
     if (bBeDirty) {
         query.exec ("PRAGMA synchronous=off");
     } else {
-        query.exec ("PRAGMA synchronous=on");
+        query.exec ("PRAGMA synchronous=full");
     }
 }//CacheDatabase::setQuickAndDirty
 
@@ -301,7 +298,6 @@ CacheDatabase::putUserPass (const QString &strUser, const QString &strPass)
 {
     QByteArray byD;
     OsDependent &osd = Singletons::getRef().getOSD ();
-    QString strQ;
 
     osd.cipher (strUser.toAscii (), byD, true);
     settings->setValue (GV_S_VAR_USER, QString (byD.toHex ()));
@@ -347,7 +343,6 @@ CacheDatabase::setContactsPass(const QString &strPass)
 {
     QByteArray byD;
     OsDependent &osd = Singletons::getRef().getOSD ();
-    QString strQ;
 
     osd.cipher (strPass.toAscii (), byD, true);
     settings->setValue (GV_S_VAR_CPASS, QString (byD.toHex ()));
@@ -1177,8 +1172,6 @@ CacheDatabase::getProxySettings (bool &bEnable,
                                  bool &bRequiresAuth,
                                  QString &user, QString &pass)
 {
-    QSqlQuery query(dbMain);
-    query.setForwardOnly (true);
     bool rv = false;
 
     settings->beginGroup (GV_PROXY_TABLE);
@@ -1411,14 +1404,14 @@ QString
 CacheDatabase::getTempDirectory()
 {
     OsDependent &osd = Singletons::getRef().getOSD ();
-    QString strTempStore = osd.getAppDirectory();
+    QString strTempStore = osd.getTmpDirectory ();
     QDir dirApp(strTempStore);
     strTempStore += QDir::separator() + tr("temp");
     if (!QFileInfo(strTempStore).exists ()) {
         dirApp.mkdir ("temp");
     }
 
-    return (strTempStore);
+    return (osd.getTmpDirectory());
 }//CacheDatabase::getTempDirectory
 
 void
